.. _source:


.. raw:: html

    </center>
    <br>

.. title:: Source


**SKULL, BONES AND NUMBER (OTP-CR-117/19)**


broker.py   errors.py   __init__.py   modules    persist.py   timer.py
client.py   event.py    interface.py  object.py  repeater.py  utils.py
default.py  handler.py  __main__.py   parser.py  thread.py    workdir.py


.. autosummary::
    :toctree: 
    :template: base.rst



    sbn.broker		list of bots
    sbn.client		clients
    sbn.default		default values
    sbn.errors		deferred exception handling
    sbn.event		basic event
    sbn.handler		event handler
    sbn.interface	import all
    sbn.object		clean namespace
    sbn.parser		command parser
    sbn.persist		persistence
    sbn.repeater	repeaters
    sbn.thread		threads
    sbn.timer		timers
    sbn.utils		utilitites
    sbn.workdir		working directory


**MODULES**


.. autosummary::
    :toctree: 
    :template: base.rst

    sbn.modules.cmd 	list of commands
    sbn.modules.err     show errors
    sbn.modules.flt     list of bots
    sbn.modules.fnd     locate objects
    sbn.modules.irc     internet realy chat
    sbn.modules.log     log text
    sbn.modules.mbx     mailbox
    sbn.modules.mdl     model
    sbn.modules.mod     list of modules
    sbn.modules.req	request
    sbn.modules.rss     rich site syndicate
    sbn.modules.rst     rest server
    sbn.modules.tdo     todo items
    sbn.modules.thr     list of threads
    sbn.modules.tmr     timers
    sbn.modules.udp     udp to irc relay
